
% FIGS 3-5 STELLATE CELL PAPER

% THIS CODE IS A COPY OF figXrow1 PLUS ADDITIONAL CODE TO GENERATE PANELS
% f-i

% NOTE!!!! THE PROGRAM GENERATES DATA FOR 6 SETS OF STELLATE CELLS AND 5
% PCs PER FIELD. IN FACT THAT IS TOO MANY. THERE ARE 5 SETS OF SCs AND 4
% PCs IN A FIELD. THE FIGURES USE DATA FOR 5 AND 4.

M = 3645; % Assumes a terminal to gr cell divergence ratio of 1:50

terminals = 700; % the total number of terminals per field, derived from 
% 8750 gr cells per field and mf terminal to gr cell divergence of 1:50

% NOTE The values of M and terminals will change if the terminal to gr 
% cell ratio changes

mf = 182; % The number of mossy fibres that innervate a field, an estimate 
% derived in the mf stats code paper

ranks = 41; % The number of ranks that supply parallel fibre input to a 
% microzone in the middle
files = 100; % The number of files that cross ranks at right angles

% (1) GENERATE MOSSY FIBRE RATES RECEIVED BY EACH RANK
% Randomly generates values that represent mossy fibre rates received as 
% input to a rank. The number of rates is equal to the number of mossy
% fibres which innervate a rank.  

% % UNIFORM RANDOM DISTRIBUTION
% % The physiological range of mf firing rates in the behaving animal is 
% % 50-300 Hz. The region providing pf input to a microzone can be thought of
% % as divided functionally into 41 ranks crossed by 100 files
% 
% rankrates = zeros(M,ranks); % preallocates storage for an M x ranks matrix
% murank = zeros(1,ranks);
% sigrank = zeros(1,ranks);
% for i = 1:ranks
%     rankrates(:,i) = randi([50 300],1,M)'; % each iteration of the loop 
%     % creates a column vector of M integers randomly generated in the range
%     % 50-300, representing mossy fibre rates received as input to a rank,
%     % with a uniform distribution (i.e. all values are equally likely)
%     murank = mean(rankrates(:,i));
%     sigrank = std(rankrates(:,i));
% end

% RANDOMLY SAMPLED FROM A NORMAL DISTRIBUTION WITH SPECIFIED MEAN AND SD
m = 175;
% sd = 12.5;
sd = 40;
% sd = 50;

for i = 1:ranks
    rankrates(:,i) = sd.*randn(1,M) + m; % array of M integers randomly 
    % drawn from a normal distribution with mean m and standard deviation 
    % sd
    murank = mean(rankrates(:,i));
    sigrank = std(rankrates(:,i));
end

% (2) SAMPLE MF RATES RECEIVED BY A RANK TO DERIVE RATES RECEIVED BY EACH
% FIELD

fieldrates = cell(files,ranks); % preallocates space for a files x ranks cell 
% matrix
for i = 1:files
    for j = 1:ranks
        sample = datasample(rankrates(:,j),mf);
        fieldrates{i,j} = sample; % each iteration of the loop populates a 
        % cell with mf rates randomly sampled from column j of rankrates
    end
end

% (3) ADD COPIES TO RATES RECEIVED BY EACH FIELD

% mfs contribute a variable number of terminals to a field (each field is 
% represented by a cell in fieldrates).

for i = 1:files
    for j = 1:ranks
        a = [];
        hz = fieldrates{i,j};
        for k = 1:length(hz)
            factor = randi(7); % randomly generated number in the range 1-7
            b = hz(k).*ones(1,factor); % makes copies of each value in the 
            % cell at fieldrates{i,j}. The number of copies is equal to
            % factor
            a = [a b];
        end
        fieldrates{i,j} = a;
    end
end

% (4) SAMPLE MF RATES IN EACH FIELD TO REPRESENT INPUT TO GR CELLS. TAKE 
% THE MEAN OF EACH SAMPLE AND THE TOP SLICE FOR EACH FIELD

grcellmeans = cell(files,ranks); % Preallocates space
activegrcellmeans = cell(files,ranks);
for i = 1:files
    for j = 1:ranks
        samplemeans = zeros(1,8750); % Preallocates space
        for k = 1:8750
            samplemeans(k) = mean(datasample(fieldrates{i,j},4)); 
        end
        grcellmeans{i,j} = samplemeans; % assigns the sample means to a 
        % cell in grcellmeans. Each cell represents a field. This data
        % isn't graphed but stored away just in case
        order = sort(samplemeans); % puts samplemeans in ascending order
        toporder = order(end-43:end); % 1 x 44 array, the top slice of the
        % gr cell sample means
        activegrcellmeans{i,j} = toporder; % assigns the top slice to a 
        % cell in activegrcellmeans. Each cell represents a field. 
    end
    i
end

% (5) PUT GR CELL RATES IN A ROW OF FIELDS INTO A SINGLE CELL TO REPRESENT
% PF RATES 

pfrates = cell(files,1); % creates a 100 x 1 empty cell array

for i = 1:files % for each row...
    e = [];
    for j = 1:ranks % ...and within each row, each column...
        f = activegrcellmeans{i,j};
        e = [e f];
    end
    pfrates{i,1} = e; % populates the cell array. Each cell contains a 1 x 
    % 1,804 array. (1,804 is derived from 44 sample means per field x 41
    % columns.)
end

% % % (6) PLOT PF RATES RECEIVED BY A FIELD SELECTED AT RANDOM IN THE MIDDLE
% % % RANK
% % 
% % field = randi(files);
% % 
% % subplot(3,5,[1 6])
% % x = 1:length(pfrates{field,1});
% % 
% % plot(x,pfrates{field,1},'color',[.74  .93  .67],'LineWidth',1.25); 
% % xlabel('signals'); ylabel('common scale'); title('pf: a file'); 
% % xlim([0 1804]);
% % ylim([250 300]); 
% % yticks([250 260 270 280 290 300]); yticklabels([0 10 20 30 40 50]);
% % set(gca,'FontSize',11)

% (7) DERIVE THE NUMBER AND FIRING RATE OF ACTIVE INPUTS TO 16 STELLATE
% CELLS IN EACH FIELD OF THE CENTRE RANK, AND THE MEAN OF RATES RECEIVED BY
% EACH CELL

SCinputs1 = cell(files,16); % files x 16 empty cell array
SCmeans1 = zeros(files,16);
for i = 1:files
    for j = 1:16
        example = datasample(pfrates{i,1},1);
        TB = inputs(); % a function that returns a number between 1 and 
        % 12 representing the number of active inputs to a stellate
        % cell
        if TB == 0
            sample = example;
        else
            sample = datasample(pfrates{i,1},TB);
        end
        SCinputs1{i,j} = sample; % each iteration of the j  
        % loop populates a cell with pf rates received by a stellate cell; 
        % there are 16 samples because there are 16 stellate cells per
        % PC; sample size is randomly variable with the Table B
        % probabilities; the sampled population is pfrates{i,1}.

        muSC = mean(sample); % The mean rate of input to a stellate cell...
        SCmeans1(i,j) = muSC; %...is assigned to index position i,j in 
        % the 100 x 16 matrix SCmeans 
    end
end

% (8) REPEAT STEP (7) FIVE TIMES TO DERIVE THE SAME DATA FOR A SECOND,
% THIRD, FOURTH, FIFTH AND SIXTH SET OF 16 STELLATE CELLS IN EACH FIELD, 
% ALSO IN THE CENTRE RANK

% second set
SCinputs2 = cell(files,16); % files x 16 empty cell array
SCmeans2 = zeros(files,16);
for i = 1:files
    for j = 1:16
        example = datasample(pfrates{i,1},1);
        TB = inputs(); % a function that returns a number between 1 and 
        % 12 representing the number of active inputs to a stellate
        % cell
        if TB == 0
            sample = example;
        else
            sample = datasample(pfrates{i,1},TB);
        end
        SCinputs2{i,j} = sample; % each iteration of the j  
        % loop populates a cell with pf rates received by a stellate cell; 
        % there are 16 samples because there are 16 stellate cells per
        % PC; sample size is randomly variable with the Table B
        % probabilities; the sampled population is pfrates{i,1}.

        muSC = mean(sample); % The mean rate of input to a stellate cell...
        SCmeans2(i,j) = muSC; %...is assigned to index position i,j in 
        % the 100 x 16 matrix SCmeans2 
    end
end

% third set
SCinputs3 = cell(files,16); % files x 16 empty cell array
SCmeans3 = zeros(files,16);
for i = 1:files
    for j = 1:16
        example = datasample(pfrates{i,1},1);
        TB = inputs(); % a function that returns a number between 1 and 
        % 12 representing the number of active inputs to a stellate
        % cell
        if TB == 0
            sample = example;
        else
            sample = datasample(pfrates{i,1},TB);
        end
        SCinputs3{i,j} = sample; % each iteration of the j  
        % loop populates a cell with pf rates received by a stellate cell; 
        % there are 16 samples because there are 16 stellate cells per
        % PC; sample size is randomly variable with the Table B
        % probabilities; the sampled population is pfrates{i,1}.

        muSC = mean(sample); % The mean rate of input to a stellate cell...
        SCmeans3(i,j) = muSC; %...is assigned to index position i,j in 
        % the 100 x 16 matrix SCmeans2 
    end
end

% fourth set
SCinputs4 = cell(files,16); % files x 16 empty cell array
SCmeans4 = zeros(files,16);
for i = 1:files
    for j = 1:16
        example = datasample(pfrates{i,1},1);
        TB = inputs(); % a function that returns a number between 1 and 
        % 12 representing the number of active inputs to a stellate
        % cell
        if TB == 0
            sample = example;
        else
            sample = datasample(pfrates{i,1},TB);
        end
        SCinputs4{i,j} = sample; % each iteration of the j  
        % loop populates a cell with pf rates received by a stellate cell; 
        % there are 16 samples because there are 16 stellate cells per
        % PC; sample size is randomly variable with the Table B
        % probabilities; the sampled population is pfrates{i,1}.

        muSC = mean(sample); % The mean rate of input to a stellate cell...
        SCmeans4(i,j) = muSC; %...is assigned to index position i,j in 
        % the 100 x 16 matrix SCmeans2 
    end
end

% fifth set
SCinputs5 = cell(files,16); % files x 16 empty cell array
SCmeans5 = zeros(files,16);
for i = 1:files
    for j = 1:16
        example = datasample(pfrates{i,1},1);
        TB = inputs(); % a function that returns a number between 1 and 
        % 12 representing the number of active inputs to a stellate
        % cell
        if TB == 0
            sample = example;
        else
            sample = datasample(pfrates{i,1},TB);
        end
        SCinputs5{i,j} = sample; % each iteration of the j  
        % loop populates a cell with pf rates received by a stellate cell; 
        % there are 16 samples because there are 16 stellate cells per
        % PC; sample size is randomly variable with the Table B
        % probabilities; the sampled population is pfrates{i,1}.

        muSC = mean(sample); % The mean rate of input to a stellate cell...
        SCmeans5(i,j) = muSC; %...is assigned to index position i,j in 
        % the 100 x 16 matrix SCmeans2 
    end
end

% sixth set
SCinputs6 = cell(files,16); % files x 16 empty cell array
SCmeans6 = zeros(files,16);
for i = 1:files
    for j = 1:16
        example = datasample(pfrates{i,1},1);
        TB = inputs(); % a function that returns a number between 1 and 
        % 12 representing the number of active inputs to a stellate
        % cell
        if TB == 0
            sample = example;
        else
            sample = datasample(pfrates{i,1},TB);
        end
        SCinputs6{i,j} = sample; % each iteration of the j  
        % loop populates a cell with pf rates received by a stellate cell; 
        % there are 16 samples because there are 16 stellate cells per
        % PC; sample size is randomly variable with the Table B
        % probabilities; the sampled population is pfrates{i,1}.

        muSC = mean(sample); % The mean rate of input to a stellate cell...
        SCmeans6(i,j) = muSC; %...is assigned to index position i,j in 
        % the 100 x 16 matrix SCmeans2 
    end
end

% (9) ADD LATERALLY POSITIONED SCs TO INHIBITION OF PCs

L = 4; % The number of lateral SC inputs to a PC from a neighbouring field

% Add lateral inhibition to the first set of stellate cell data
extras = zeros(files,2.*L);
A = datasample(SCmeans1(100,:),L);
B = datasample(SCmeans1(2,:),L);
C = [A B]; 
extras(1,:) = C;
for i = 2:files - 1
    A = datasample(SCmeans1(i - 1,:),L);
    B = datasample(SCmeans1(i + 1,:),L);
    C = [A B];
    extras(i,:) = C;
end
A = datasample(SCmeans1(99,:),L);
B = datasample(SCmeans1(1,:),L);
C = [A B]; 
extras(100,:) = C;
SCmeans1 = [SCmeans1 extras];

% (10) REPEAT STEP 9 FIVE TIMES TO ADD LATERAL INHIBITION TO THE OTHER SETS
% OF STELLATE CELLS

% Add lateral inhibition to the second set of stellate cell data
extras = zeros(files,2.*L);
A = datasample(SCmeans2(100,:),L);
B = datasample(SCmeans2(2,:),L);
C = [A B]; 
extras(1,:) = C;
for i = 2:files - 1
    A = datasample(SCmeans2(i - 1,:),L);
    B = datasample(SCmeans2(i + 1,:),L);
    C = [A B];
    extras(i,:) = C;
end
A = datasample(SCmeans2(99,:),L);
B = datasample(SCmeans2(1,:),L);
C = [A B]; 
extras(100,:) = C;
SCmeans2 = [SCmeans2 extras];

% Add lateral inhibition to the third set of stellate cell data
extras = zeros(files,2.*L);
A = datasample(SCmeans3(100,:),L);
B = datasample(SCmeans3(2,:),L);
C = [A B]; 
extras(1,:) = C;
for i = 2:files - 1
    A = datasample(SCmeans3(i - 1,:),L);
    B = datasample(SCmeans3(i + 1,:),L);
    C = [A B];
    extras(i,:) = C;
end
A = datasample(SCmeans3(99,:),L);
B = datasample(SCmeans3(1,:),L);
C = [A B]; 
extras(100,:) = C;
SCmeans3 = [SCmeans3 extras];

% Add lateral inhibition to the fourth set of stellate cell data
extras = zeros(files,2.*L);
A = datasample(SCmeans4(100,:),L);
B = datasample(SCmeans4(2,:),L);
C = [A B]; 
extras(1,:) = C;
for i = 2:files - 1
    A = datasample(SCmeans4(i - 1,:),L);
    B = datasample(SCmeans4(i + 1,:),L);
    C = [A B];
    extras(i,:) = C;
end
A = datasample(SCmeans4(99,:),L);
B = datasample(SCmeans4(1,:),L);
C = [A B]; 
extras(100,:) = C;
SCmeans4 = [SCmeans4 extras];

% Add lateral inhibition to the fifth set of stellate cell data
extras = zeros(files,2.*L);
A = datasample(SCmeans5(100,:),L);
B = datasample(SCmeans5(2,:),L);
C = [A B]; 
extras(1,:) = C;
for i = 2:files - 1
    A = datasample(SCmeans5(i - 1,:),L);
    B = datasample(SCmeans5(i + 1,:),L);
    C = [A B];
    extras(i,:) = C;
end
A = datasample(SCmeans5(99,:),L);
B = datasample(SCmeans5(1,:),L);
C = [A B]; 
extras(100,:) = C;
SCmeans5 = [SCmeans5 extras];

% Add lateral inhibition to the sixth set of stellate cell data
extras = zeros(files,2.*L);
A = datasample(SCmeans6(100,:),L);
B = datasample(SCmeans6(2,:),L);
C = [A B]; 
extras(1,:) = C;
for i = 2:files - 1
    A = datasample(SCmeans6(i - 1,:),L);
    B = datasample(SCmeans6(i + 1,:),L);
    C = [A B];
    extras(i,:) = C;
end
A = datasample(SCmeans6(99,:),L);
B = datasample(SCmeans6(1,:),L);
C = [A B]; 
extras(100,:) = C;
SCmeans6 = [SCmeans6 extras];

% (11) IN EACH FIELD, SAMPLE SC RATES TO REPRESENT INHIBITION OF PC 
% DENDRITIC SECTORS, AND TAKE THE MEAN OF INHIBITION OF EACH SECTOR

LL = 6; % The number of convergent SC inputs to a PC sector
S = 16; % The number of sectors per PC

% PC1
% Sample the first set of stellate cells
PC1sectorsA = zeros(files,S);
for i = 1:files
    for j = 1:S
        sectorsample = datasample(SCmeans1(i,:),LL);
        sectormean = mean(sectorsample);
        PC1sectorsA(i,j) = sectormean;
    end
end

% Sample the second set of stellate cells
PC1sectorsB = zeros(files,S);
for i = 1:files
    for j = 1:S
        sectorsample = datasample(SCmeans2(i,:),LL);
        sectormean = mean(sectorsample);
        PC1sectorsB(i,j) = sectormean;
    end
end

PC1sectormeans = zeros(files,S);
for i = 1:files
    for j = 1:S
        D = PC1sectorsA(i,j);
        E = PC1sectorsB(i,j);
        F = mean([D E]);
        PC1sectormeans(i,j) = F;
    end
end

% (12) REPEAT 4 TIMES REPRESENTING THE OTHER FOUR PCs IN A FIELD

% PC2
% Sample the second set of stellate cells
PC2sectorsA = zeros(files,S);
for i = 1:files
    for j = 1:S
        sectorsample = datasample(SCmeans2(i,:),LL);
        sectormean = mean(sectorsample);
        PC2sectorsA(i,j) = sectormean;
    end
end

% Sample the third set of stellate cells
PC2sectorsB = zeros(files,S);
for i = 1:files
    for j = 1:S
        sectorsample = datasample(SCmeans3(i,:),LL);
        sectormean = mean(sectorsample);
        PC2sectorsB(i,j) = sectormean;
    end
end

PC2sectormeans = zeros(files,S);
for i = 1:files
    for j = 1:S
        D = PC2sectorsA(i,j);
        E = PC2sectorsB(i,j);
        F = mean([D E]);
        PC2sectormeans(i,j) = F;
    end
end

% PC3
% Sample the third set of stellate cells
PC3sectorsA = zeros(files,S);
for i = 1:files
    for j = 1:S
        sectorsample = datasample(SCmeans3(i,:),LL);
        sectormean = mean(sectorsample);
        PC3sectorsA(i,j) = sectormean;
    end
end

% Sample the fourth set of stellate cells
PC3sectorsB = zeros(files,S);
for i = 1:files
    for j = 1:S
        sectorsample = datasample(SCmeans4(i,:),LL);
        sectormean = mean(sectorsample);
        PC3sectorsB(i,j) = sectormean;
    end
end

PC3sectormeans = zeros(files,S);
for i = 1:files
    for j = 1:S
        D = PC3sectorsA(i,j);
        E = PC3sectorsB(i,j);
        F = mean([D E]);
        PC3sectormeans(i,j) = F;
    end
end

% PC4
% Sample the fourth set of stellate cells
PC4sectorsA = zeros(files,S);
for i = 1:files
    for j = 1:S
        sectorsample = datasample(SCmeans4(i,:),LL);
        sectormean = mean(sectorsample);
        PC4sectorsA(i,j) = sectormean;
    end
end

% Sample the fifth set of stellate cells
PC4sectorsB = zeros(files,S);
for i = 1:files
    for j = 1:S
        sectorsample = datasample(SCmeans5(i,:),LL);
        sectormean = mean(sectorsample);
        PC4sectorsB(i,j) = sectormean;
    end
end

PC4sectormeans = zeros(files,S);
for i = 1:files
    for j = 1:S
        D = PC4sectorsA(i,j);
        E = PC4sectorsB(i,j);
        F = mean([D E]);
        PC4sectormeans(i,j) = F;
    end
end

% PC5
% Sample the fifth set of stellate cells
PC5sectorsA = zeros(files,S);
for i = 1:files
    for j = 1:S
        sectorsample = datasample(SCmeans5(i,:),LL);
        sectormean = mean(sectorsample);
        PC5sectorsA(i,j) = sectormean;
    end
end

% Sample the sixth set of stellate cells
PC5sectorsB = zeros(files,S);
for i = 1:files
    for j = 1:S
        sectorsample = datasample(SCmeans6(i,:),LL);
        sectormean = mean(sectorsample);
        PC5sectorsB(i,j) = sectormean;
    end
end

PC5sectormeans = zeros(files,S);
for i = 1:files
    for j = 1:S
        D = PC5sectorsA(i,j);
        E = PC5sectorsB(i,j);
        F = mean([D E]);
        PC5sectormeans(i,j) = F;
    end
end

% (12.5) PLOT SC INPUT TO A SINGLE PC. (THIS PANEL AND CODE WAS A LAST
% MINUTE ADDITION)

OnePCA = [];
for j = 1:S
    sectorsample = datasample(SCmeans1(i,:),LL);
    OnePCA = [OnePCA sectorsample];
end
OnePCB = [];
for j = 1:S
    sectorsample = datasample(SCmeans2(i,:),LL);
    OnePCB = [OnePCB sectorsample];
end

% % Merge OnePCA and OnePCB
% data1 = [OnePCA(:) OnePCB(:)]';
% data1 = data1(:)';
% 
% subplot(1,5,1)
% x = 1:length(data1);
% plot(x,data1,'LineStyle','none','Marker','o','MarkerSize',3,'color',[0 0 .4],'MarkerFaceColor',[.62 .74 .83]); 
% xlabel('SC signals'); ylabel('common scale'); title('one PC: home'); 
% ylim([220 240]); 
% set(gca,'FontSize',11)

% (13) PLOT SECTOR INHIBITION FOR PC1, FIRST FOR ONE SET OF 16 AFFERENT 
% STELLATE CELLS, THEN BOTH. DATA REPRESENT INHIBITION OF A SINGLE PC IN
% EACH FIELD 

% Convert PC1sectorsA to a row vector
data2 = PC1sectorsA'; data2 = data2(:)';

subplot(1,5,1)
x = 1:length(data2);
plot(x,data2,'LineStyle','none','Marker','o','MarkerSize',2,'color',[.82 .7 .55],'MarkerFaceColor',[.58 .35 0]); 
xlabel('compts., 100 PCs'); ylabel('normalised scale - range 60'); title('PC compt. means'); 
ylim([202 262]); 
set(gca,'FontSize',11)

% Convert PC1sectormeans to a row vector
data3 = PC1sectormeans'; data3 = data3(:)';

subplot(1,5,2)
x = 1:length(data3);
plot(x,data3,'LineStyle','none','Marker','o','MarkerSize',2,'color',[.82 .7 .55],'MarkerFaceColor',[.58 .35 0]); 
xlabel('compts., 100 PCs'); ylabel(''); title('avgd compt. means'); 
ylim([202 262]); 
set(gca,'FontSize',11)

% (14) TAKE THE MEAN OF THE SECTOR MEANS FOR EACH PC, REPRESENTING THE
% INTEGRATED EFFECT ON PC SOMATIC MEMBRANE POTENTIAL. 

% Convert PC1sectormeans to PC1means, a 1 x 100 array
flip = PC1sectormeans'; 
PC1means = mean(flip);

% Repeat
flip = PC2sectormeans'; 
PC2means = mean(flip);

flip = PC3sectormeans'; 
PC3means = mean(flip);

flip = PC4sectormeans'; 
PC4means = mean(flip);

flip = PC5sectormeans'; % Not used
PC5means = mean(flip); % Not used

% (15) PLOT PC DATA FOR THE CENTRE RANK

PCrankmeans = [PC1means; PC2means; PC3means; PC4means];
PCrankmeans = PCrankmeans(:)';

subplot(1,5,3)
x = 1:length(PCrankmeans);
plot(x,PCrankmeans,'LineStyle','none','Marker','o','MarkerSize',2,'Color',[0 .4 0],'MarkerFaceColor',[.64 .83 .57]); 
xlabel('PCs'); ylabel(''); title('PC soma'); 
xlim([0 400]); xticks([0 100 200 300 400]); xticklabels([0 100 200 300 400]);
ylim([202 262]);
set(gca,'FontSize',11)

subplot(1,5,4)
x = 1:length(PCrankmeans);
plot(x,PCrankmeans,'LineStyle','none','Marker','o','MarkerSize',3,'Color',[0 .4 0],'MarkerFaceColor',[.64 .83 .57]); 
xlabel('PCs'); ylabel('normalised scale - range 10'); title('PC soma'); 
xlim([0 400]); xticks([0 100 200 300 400]); xticklabels([0 100 200 300 400]);
ylim([227 237]); yticks([227 228 229 230 231 232 233 234 235 236 237]);
set(gca,'FontSize',11)

% (16) TAKE 50 RANDOM SAMPLES OF PC DATA (BECAUSE THERE ARE 50 NUCLEAR 
% CELLS) AND TAKE AND PLOT THE SAMPLE MEANS

% Note: in an earlier version, this panel was used to plot the mean of PC
% data for each field in the middle rank

% PCmeansmatrix = [PC1means; PC2means; PC3means; PC4means];
% fieldPCmeans = mean(PCmeansmatrix); % 1 x 100

nuclearmeans = zeros(1,50);

for i = 1:50
    num = randi([30,50]);
    nuclearsample = datasample(PCrankmeans,num);
    nuclearsamplemean = mean(nuclearsample);
    nuclearmeans(1,i) = nuclearsamplemean;
end

subplot(1,5,5)
x = 1:length(nuclearmeans);
plot(x,nuclearmeans,'LineStyle','none','Marker','o','MarkerSize',3,'Color',[.6 0 0],'MarkerFaceColor',[1 .8 .8]); 
xlabel('nuclear cells'); ylabel(''); title('nuclear group'); 
xlim([0 50]); xticks([0 10 20 30 40 50]); xticklabels([0 10 20 30 40 50]);
ylim([227 237]); yticks([227 228 229 230 231 232 233 234 235 236 237]);
set(gca,'FontSize',11)

% THE COMMENTED CODE BELOW IS AN EARLIER DRAFT OF WHAT BECAME FIG 4, PLUS
% SOME EARLIER CODE

% % (16) DERIVE EXCITATORY SECTOR MEANS, i.e., THE MEAN OF EXCITATORY INPUT 
% % TO EACH SECTOR, 1 PC PER FIELD, CENTRE RANK. PLOTTED AS PANEL 9
% 
% excitatory_inputs = cell(files,16);
% excitatory_sectormeans1 = zeros(files,16);
% 
% for i = 1:files
%     for j = 1:16
%         samp = randsample(pfrates{i,1},112);
%         excitatory_inputs{i,j} = samp;
%         musamp = mean(samp);
%         excitatory_sectormeans1(i,j) = musamp;
%     end
%     i
% end
% 
% % Convert excitatory_sectormeans1 to a row vector
% y = excitatory_sectormeans1'; y = y(:)';
% 
% subplot(1,10,9)
% x = 1:length(y);
% plot(x,y,'LineStyle','none','Marker','o','MarkerSize',2,'color',[.2 .2 .2],'MarkerFaceColor',[.57 .51 .32]); 
% xlabel('sectors'); ylabel(''); title('0/100'); 
% ylim([260 280]); %yticklabels([]);
% set(gca,'FontSize',11)
% 
% % (17) DERIVE EXCITATORY SECTOR MEANS FOR THE OTHER 3 PCs PER FIELD
% 
% excitatory_inputs = cell(files,16);
% excitatory_sectormeans2 = zeros(files,16);
% 
% for i = 1:files
%     for j = 1:16
%         samp = randsample(pfrates{i,1},112);
%         excitatory_inputs{i,j} = samp;
%         musamp = mean(samp);
%         excitatory_sectormeans2(i,j) = musamp;
%     end
%     i
% end
% 
% excitatory_inputs = cell(files,16);
% excitatory_sectormeans3 = zeros(files,16);
% 
% for i = 1:files
%     for j = 1:16
%         samp = randsample(pfrates{i,1},112);
%         excitatory_inputs{i,j} = samp;
%         musamp = mean(samp);
%         excitatory_sectormeans3(i,j) = musamp;
%     end
%     i
% end
% 
% excitatory_inputs = cell(files,16);
% excitatory_sectormeans4 = zeros(files,16);
% 
% for i = 1:files
%     for j = 1:16
%         samp = randsample(pfrates{i,1},112);
%         excitatory_inputs{i,j} = samp;
%         musamp = mean(samp);
%         excitatory_sectormeans4(i,j) = musamp;
%     end
%     i
% end
% 
% % (18) TAKE THE MEAN OF THE EXCITATORY SECTOR MEANS FOR EACH PC, 
% % REPRESENTING THE INTEGRATED EFFECT ON PC SOMATIC MEMBRANE POTENTIAL.
% 
% % Convert excitatory_sectormeans1 to excitatory_means1, a 1 x 100 array
% flip = excitatory_sectormeans1'; 
% excitatory_means1 = mean(flip);
% 
% % Repeat
% flip = excitatory_sectormeans2'; 
% excitatory_means2 = mean(flip);
% 
% flip = excitatory_sectormeans3'; 
% excitatory_means3 = mean(flip);
% 
% flip = excitatory_sectormeans4'; 
% excitatory_means4 = mean(flip);
% 
% % (19) PLOT EXCITATORY DATA FOR THE CENTRE RANK. PANEL 10
% 
% excitatory_rankmeans = [excitatory_means1; excitatory_means2;...
%     excitatory_means3; excitatory_means4];
% excitatory_rankmeans = excitatory_rankmeans(:)';
% 
% subplot(1,10,10)
% x = 1:length(excitatory_rankmeans);
% plot(x,excitatory_rankmeans,'LineStyle','none','Marker','o','MarkerSize',2,'Color',[0 .4 0],'MarkerFaceColor',[.64 .83 .57]); 
% xlabel('PCs'); ylabel(''); title('soma'); 
% xlim([0 400]); xticks([0 100 200 300 400]); xticklabels([0 100 200 300 400]);
% ylim([260 280]); yticklabels([]);
% set(gca,'FontSize',11)
% 
% % (20) FOR 1 PC IN EACH FIELD, TAKE THE MEAN BY ELEMENT OF INHIBITORY AND 
% % EXCITATORY SECTOR MEANS TO CREATE A NEW MATRIX OF THE SAME SIZE. THEN 
% % TAKE THE MEAN OF THE SECTOR MEANS TO REPRESENT SOMATIC MEMBRANE POTENTIAL. 
% % REPEAT FOR THE OTHER 3 PCs PER FIELD. PANELS 5 AND 6.
% 
% sectormeans1_5050 = (PC1sectormeans + excitatory_sectormeans1)/2; % 100 x 16 matrix
% flip = sectormeans1_5050'; % 16 x 100 matrix
% avgdmeans1_5050 = mean(flip); % 1 x 100 matrix
% 
% sectormeans2_5050 = (PC2sectormeans + excitatory_sectormeans2)/2;
% flip = sectormeans2_5050';
% avgd_means2_5050 = mean(flip);
% 
% sectormeans3_5050 = (PC3sectormeans + excitatory_sectormeans3)/2;
% flip = sectormeans3_5050';
% avgd_means3_5050 = mean(flip);
% 
% sectormeans4_5050 = (PC4sectormeans + excitatory_sectormeans4)/2;
% flip = sectormeans4_5050';
% avgdmeans4_5050 = mean(flip);
% 
% % Convert sectormeans1_5050 to a row vector
% y = sectormeans1_5050'; y = y(:)';
% 
% subplot(1,10,5)
% x = 1:length(y);
% plot(x,y,'LineStyle','none','Marker','o','MarkerSize',2,'color',[.2 .2 .2],'MarkerFaceColor',[.57 .51 .32]); 
% xlabel('sectors'); ylabel(''); title('50/50'); 
% ylim([260 280]); %yticklabels([]);
% set(gca,'FontSize',11)
% 
% % Merge the PC data into a 1 X 400 array to represent the PC population of
% % the centre rank
% merged_avgdmeans_5050 = [avgdmeans1_5050; avgd_means2_5050;...
%     avgd_means3_5050; avgdmeans4_5050];
% merged_avgdmeans_5050 = merged_avgdmeans_5050(:)';
% 
% subplot(1,10,6)
% x = 1:length(merged_avgdmeans_5050);
% plot(x,merged_avgdmeans_5050,'LineStyle','none','Marker','o','MarkerSize',2,'Color',[0 .4 0],'MarkerFaceColor',[.64 .83 .57]); 
% xlabel('PCs'); ylabel(''); title('soma'); 
% xlim([0 400]); xticks([0 100 200 300 400]); xticklabels([0 100 200 300 400]);
% ylim([260 280]); yticklabels([]);
% set(gca,'FontSize',11)
% 
% % REPEAT, BUT USING THE 50/50 SECTOR MEANS TO DERIVE 75/25 SECTOR MEANS
% % (INHIBITORY/EXCITATORY), THEN USING THE NEW DATA TO DERIVE PC DATA FOR 
% % THE CENTRE RANK, AS BEFORE. PLOTTED AS PANELS 3 AND 4.
% 
% sectormeans1_7525 = (PC1sectormeans + sectormeans1_5050)/2; % 100 x 16 matrix
% flip = sectormeans1_7525'; % 16 x 100 matrix
% avgdmeans1_7525 = mean(flip); % 1 x 100 matrix
% 
% sectormeans2_7525 = (PC2sectormeans + sectormeans2_5050)/2;
% flip = sectormeans2_7525';
% avgd_means2_7525 = mean(flip);
% 
% sectormeans3_7525 = (PC3sectormeans + sectormeans3_5050)/2;
% flip = sectormeans3_7525';
% avgd_means3_7525 = mean(flip);
% 
% sectormeans4_7525 = (PC4sectormeans + sectormeans4_5050)/2;
% flip = sectormeans4_7525';
% avgdmeans4_7525 = mean(flip);
% 
% % Convert sectormeans1_7525 to a row vector
% y = sectormeans1_7525'; y = y(:)';
% 
% subplot(1,10,3)
% x = 1:length(y);
% plot(x,y,'LineStyle','none','Marker','o','MarkerSize',2,'color',[.2 .2 .2],'MarkerFaceColor',[.57 .51 .32]); 
% xlabel('sectors'); ylabel(''); title('75/25'); 
% ylim([260 280]); %yticklabels([]);
% set(gca,'FontSize',11)
% 
% % Merge the PC data into a 1 X 400 array to represent the PC population of
% % the centre rank
% merged_avgdmeans_7525 = [avgdmeans1_7525; avgd_means2_7525;...
%     avgd_means3_7525; avgdmeans4_7525];
% merged_avgdmeans_7525 = merged_avgdmeans_7525(:)';
% 
% subplot(1,10,4)
% x = 1:length(merged_avgdmeans_7525);
% plot(x,merged_avgdmeans_7525,'LineStyle','none','Marker','o','MarkerSize',2,'Color',[0 .4 0],'MarkerFaceColor',[.64 .83 .57]); 
% xlabel('PCs'); ylabel(''); title('soma'); 
% xlim([0 400]); xticks([0 100 200 300 400]); xticklabels([0 100 200 300 400]);
% ylim([260 280]); yticklabels([]);
% set(gca,'FontSize',11)
% 
% % REPEAT AGAIN, BUT USING THE 50/50 SECTOR MEANS TO DERIVE 25/75 SECTOR 
% % MEANS (INHIBITORY/EXCITATORY), THEN USING THE NEW DATA TO DERIVE PC DATA  
% % FOR THE CENTRE RANK, AS BEFORE. PLOTTED AS PANELS 7 AND 8
% 
% sectormeans1_2575 = (sectormeans1_5050 + excitatory_sectormeans1)/2; % 100 x 16 matrix
% flip = sectormeans1_2575'; % 16 x 100 matrix
% avgdmeans1_2575 = mean(flip); % 1 x 100 matrix
% 
% sectormeans2_2575 = (sectormeans2_5050 + excitatory_sectormeans2)/2;
% flip = sectormeans2_2575';
% avgd_means2_2575 = mean(flip);
% 
% sectormeans3_2575 = (sectormeans3_5050 + excitatory_sectormeans3)/2;
% flip = sectormeans3_2575';
% avgd_means3_2575 = mean(flip);
% 
% sectormeans4_2575 = (sectormeans4_5050 + excitatory_sectormeans4)/2;
% flip = sectormeans4_2575';
% avgdmeans4_2575 = mean(flip);
% 
% % Convert sectormeans1_5050 to a row vector
% y = sectormeans1_2575'; y = y(:)';
% 
% subplot(1,10,7)
% x = 1:length(y);
% plot(x,y,'LineStyle','none','Marker','o','MarkerSize',2,'color',[.2 .2 .2],'MarkerFaceColor',[.57 .51 .32]); 
% xlabel('sectors'); ylabel(''); title('25/75'); 
% ylim([260 280]); %yticklabels([]);
% set(gca,'FontSize',11)
% 
% % Merge the PC data into a 1 X 400 array to represent the PC population of
% % the centre rank
% merged_avgdmeans_2575 = [avgdmeans1_2575; avgd_means2_2575;...
%     avgd_means3_2575; avgdmeans4_2575];
% merged_avgdmeans_2575 = merged_avgdmeans_2575(:)';
% 
% subplot(1,10,8)
% x = 1:length(merged_avgdmeans_2575);
% plot(x,merged_avgdmeans_2575,'LineStyle','none','Marker','o','MarkerSize',2,'Color',[0 .4 0],'MarkerFaceColor',[.64 .83 .57]); 
% xlabel('PCs'); ylabel(''); title('soma'); 
% xlim([0 400]); xticks([0 100 200 300 400]); xticklabels([0 100 200 300 400]);
% ylim([260 280]); yticklabels([]);
% set(gca,'FontSize',11)
% 
% 
% % REMAINING CODE IS FOR VARIOUS PLOTS USED IN PRIOR DRAFTS %
% 
% % subplot(1,5,4)
% % x = 1:length(PCrankmeans);
% % plot(x,PCrankmeans,'LineStyle','none','Marker','o','MarkerSize',3,'Color',[0 .4 0],'MarkerFaceColor',[.64 .83 .57]); 
% % xlabel('PCs'); ylabel(''); title('PC integrated'); 
% % xlim([0 400]); xticks([0 100 200 300 400]); xticklabels([0 100 200 300 400]);
% % ylim([265 275]); yticks([265 266 267 268 269 270 271 272 273 274 275]);
% % set(gca,'FontSize',11)
% 
% % % (16) TAKE 50 RANDOM SAMPLES OF PC DATA (BECAUSE THERE ARE 50 NUCLEAR 
% % % CELLS) AND TAKE AND PLOT THE SAMPLE MEANS
% % 
% % % Note: in an earlier version, this panel was used to plot the mean of PC
% % % data for each field in the middle rank
% % 
% % % PCmeansmatrix = [PC1means; PC2means; PC3means; PC4means];
% % % fieldPCmeans = mean(PCmeansmatrix); % 1 x 100
% % 
% % nuclearmeans = zeros(1,50);
% % 
% % for i = 1:50
% %     num = randi([30,50]);
% %     nuclearsample = datasample(PCrankmeans,num);
% %     nuclearsamplemean = mean(nuclearsample);
% %     nuclearmeans(1,i) = nuclearsamplemean;
% % end
% % 
% % subplot(1,5,4)
% % x = 1:length(nuclearmeans);
% % plot(x,nuclearmeans,'LineStyle','none','Marker','o','MarkerSize',3,'Color',[.4 0 0],'MarkerFaceColor',[.8 .65 .65]); 
% % xlabel('nuclear cells'); ylabel(''); title('nuclear group'); 
% % xlim([0 50]); xticks([0 10 20 30 40 50]); xticklabels([0 10 20 30 40 50]);
% % ylim([260 280]); % yticks([265 266 267 268 269 270 271 272 273 274 275]);
% % set(gca,'FontSize',11)
% 
% % subplot(3,5,[5 10])
% % x = 1:length(fieldPCmeans);
% % plot(x,fieldPCmeans,'LineStyle','-','color',[0 .27 0],'Marker','.','MarkerSize',6.5,'color',[0 .27 0]); 
% % xlabel('fields'); ylabel(''); title('PC file means'); 
% % xlim([0 100]); xticks([0 20 40 60 80 100]); xticklabels([0 20 40 60 80 100]);
% % ylim([265 275]); 
% % set(gca,'FontSize',11)
% 
% % % (17) ZOOM IN
% % 
% % subplot(3,5,[5 10])
% % x = 1:length(fieldPCmeans);
% % plot(x,fieldPCmeans,'LineStyle','none','Marker','.','MarkerSize',6,'color',[0 0 .27]); 
% % xlabel('fields'); ylabel('enlarged scale'); title('output: home rank'); 
% % xlim([1 100]); xticks([20 40 60 80 100]); xticklabels([20 40 60 80 100]);
% % ylim([245 295]); 
% % set(gca,'FontSize',11)
